@@ -6,11 +6,11 @@ from dcim.choices import DeviceStatusChoices
 from dcim.models import Device
 from ipam.models import IPAddress
 from netbox_config_backup.models import Backup
-from utilities.forms import BootstrapMixin, DynamicModelChoiceField
+from utilities.forms import BootstrapMixin, DynamicModelChoiceField, DynamicModelMultipleChoiceField
 
-__all = (
-    'VirtualCircuitForm',
-    'VirtualCircuitInterfaceForm',
+__all__ = (
+    'BackupForm',
+    'BackupFilterSetForm',
 )
 
 
@@ -35,7 +35,7 @@ class BackupForm(BootstrapMixin, forms.ModelForm):
     )
     class Meta:
         model = Backup
-        fields = ('name', 'device', 'ip')
+        fields = ('name', 'device', 'status', 'ip')
 
     def clean(self):
         super().clean()
@@ -43,15 +43,35 @@ class BackupForm(BootstrapMixin, forms.ModelForm):
             self.cleaned_data['ip'] = None
 
 
-class BackupFiltersetForm(BootstrapMixin, forms.Form):
+class BackupFilterSetForm(BootstrapMixin, forms.Form):
     model = Backup
     field_order = [
-        'q', 'name', 'device'
+        'q', 'name', 'device_id', 'ip'
     ]
     q = forms.CharField(
         required=False,
         widget=forms.TextInput(attrs={'placeholder': _('All Fields')}),
         label=_('Search')
     )
+    device_id = DynamicModelMultipleChoiceField(
+        queryset=Device.objects.all(),
+        required=False,
+        label=_('Device'),
+        fetch_trigger='open',
+        query_params={
+            'status': [DeviceStatusChoices.STATUS_ACTIVE],
+            'platform__napalm__ne': None,
+            'has_primary_ip': True,
+        }
+    )
+    ip = forms.CharField(
+        required=False,
+        widget=forms.TextInput(
+            attrs={
+                'placeholder': 'IP Address',
+            }
+        ),
+        label=_('IP Address')
+    )
 
 
